@@ -12,8 +12,7 @@ from decimal import Decimal
 from pint import Quantity
 from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union, cast
 
-from quantityfield.helper import check_matching_unit_dimension
-
+from .helper import check_matching_unit_dimension
 from .units import ureg
 from .widgets import QuantityWidget
 
@@ -171,7 +170,7 @@ class QuantityFieldMixin(object):
     def from_db_value(self, value: Any, *args, **kwargs) -> Optional[Quantity]:
         if value is None:
             return None
-        return self.ureg.Quantity(value * getattr(self.ureg, self.base_units))
+        return self.ureg.Quantity(value, getattr(self.ureg, self.base_units))
 
     def to_python(self, value) -> Optional[Quantity]:
         if isinstance(value, Quantity):
@@ -188,7 +187,7 @@ class QuantityFieldMixin(object):
 
         value = cast(NUMBER_TYPE, to_number(value))
 
-        return self.ureg.Quantity(value * getattr(self.ureg, self.base_units))
+        return self.ureg.Quantity(value, getattr(self.ureg, self.base_units))
 
     def clean(self, value, model_instance) -> Quantity:
         """
@@ -297,7 +296,6 @@ class QuantityFormFieldMixin(object):
         super(QuantityFormFieldMixin, self).__init__(*args, **kwargs)
 
     def prepare_value(self, value):
-
         if isinstance(value, Quantity):
             return value.to(self.base_units)
         else:
@@ -333,7 +331,7 @@ class QuantityFormFieldMixin(object):
         except (ValueError, TypeError):
             raise ValidationError(self.error_messages["invalid"], code="invalid")
 
-        val = self.ureg.Quantity(val * getattr(self.ureg, units)).to(self.base_units)
+        val = self.ureg.Quantity(val, getattr(self.ureg, units)).to(self.base_units)
         self.validate(val.magnitude)
         self.run_validators(val.magnitude)
         return val
